#################################
Code shared across pypath modules
#################################

Mostly minor code fragments that are used in multiple pypath modules but not
enough good to be used outside of pypath. Most importantly, our logger.
